Page 118 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 118

Home

    are based upon sex must be exemplified scientifically. To
    demonstrate the social relations, boys and girls were
    stripped naked in the government schools to see with
    their own eyes the facts of s sex.

    When government schools were boycotted, police and
    soldiers were sent out to seek the children and force

    were beaten when they refused to repeat, "No hay Dios"
    (There is no God.) but cried out, "Hay Dios, hay Dios."
    At one point, the Secretary of State put out an order that
    children everywhere be gathered into Sunday services to
    decry God and religion and glorify atheism and
    socialism.

    and school children were taken to maternity hospitals to
    witness births. Classrooms were adorned with such

    pictures as a monk and nun in lustful approach eagerly
    disrobing. Music was also used to "defanaticize" the
    minds of the masses.

    to the

    graveyards where monuments with Christian names and
    symbols were removed and numbers only were allowed
    to be used to identify the dead. Public mockery resulted
    in the naming of a prize bull "God" and a donkey "Pope."
    In Guadalajara, fifteen year old boys and girls were
    stripped naked and forced to participate in mock
    baptisms.

    113

    Babylon's War Against God

    be socialist and scientific, and that social relations which

    them into the classrooms. At Naco, Sonora, children

    Free tickets were distributed to the lewdest movies

    Anti-Christian fanaticism even extended